package com.compdfkit.tools.search;

import android.content.Context;
import android.text.Spannable;
import android.text.SpannableStringBuilder;
import android.text.style.BackgroundColorSpan;
import android.text.style.CharacterStyle;

import androidx.core.content.ContextCompat;

import com.compdfkit.core.page.CPDFTextPage;
import com.compdfkit.core.page.CPDFTextRange;
import com.compdfkit.tools.R;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @classname：SearchTextInfo
 * @date：2018/8/23 下午1:46
 * @description：
 */
public class CSearchTextInfo {

    private Context context;
    public int page;
    public String keyword;
    public SpannableStringBuilder stringBuilder;
    public boolean isHeader;
    public int textRangeIndex;

    public CSearchTextInfo(Context context, int page, String keyword, CPDFTextPage textPage, CPDFTextRange textRange, int textRangeIndex, boolean isHeader) {
        this.context = context;
        this.page = page;
        this.keyword = keyword;
        this.isHeader = isHeader;
        this.textRangeIndex = textRangeIndex;

        if (isHeader) {
            return;
        }

        int targetStart = textRange.location - 20;
        int length;
        if (targetStart > 0) {
            length = textRange.length + 40;
        } else {
            length = textRange.length + 40 + targetStart;
            targetStart = 0;
        }
        CPDFTextRange targetTextRange = new CPDFTextRange(targetStart, length);
        String target = textPage.getText(targetTextRange);

        this.stringBuilder = highlight(target.toLowerCase(), keyword.toLowerCase());
    }

    /**
     * 关键字高亮显示
     *
     * @param text   需要显示的文字
     * @param target 需要高亮的关键字
     * @return spannable 处理完后的结果，记得不要toString()，否则没有效果
     */
    private SpannableStringBuilder highlight(String text, String target) {
        SpannableStringBuilder spannable = new SpannableStringBuilder(text);
        CharacterStyle span;
        Pattern p = Pattern.compile(target);
        Matcher m = p.matcher(text);
        int backGroundColor = ContextCompat.getColor(context, R.color.search_result_text_highlight);
        while (m.find()) {
            /****** 需要重复 ******/
            span = new BackgroundColorSpan(backGroundColor);
            spannable.setSpan(span, m.start(), m.end(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
        }
        return spannable;
    }
}
